@@ -114,11 +114,16 @@ class Main(Tools):
     '''
     # Tell user if desktop accessibility is disabled.
     self._showNoA11yDialog()
+    gobject.idle_add(self._pumpEvents)
     try:
-      pyatspi.Registry.start()
+      pyatspi.Registry.start(async=True)
     except KeyboardInterrupt:
       self._shutDown()
 
+  def _pumpEvents(self):
+    pyatspi.Registry.pumpQueuedEvents()
+    return True
+
   def _showNoA11yDialog(self):
     '''
     Shows a dialog with a relevant message when desktop accessibility seems to
@@ -127,25 +132,28 @@ class Main(Tools):
     '''
     cl = gconf.client_get_default()
     if not cl.get_bool('/desktop/gnome/interface/accessibility'):
-      message = _('Accerciser could not see the applications on your desktop.'
-                  'You must enable desktop accessibility to fix this problem.'
+      message = _('Accerciser could not see the applications on your desktop.  '
+                  'You must enable desktop accessibility to fix this problem.  '
                   'Do you want to enable it now?')
       dialog = gtk.MessageDialog(self.window,type=gtk.MESSAGE_ERROR,
                                  buttons=gtk.BUTTONS_YES_NO, 
                                  message_format=message)
-      response_id = dialog.run()
-      dialog.destroy()
-      if response_id == gtk.RESPONSE_YES:
-        cl = gconf.client_get_default()
-        cl.set_bool('/desktop/gnome/interface/accessibility', True)
-        dialog = gtk.MessageDialog(
-          self.window,
-          type=gtk.MESSAGE_INFO,
-          buttons=gtk.BUTTONS_OK, 
-          message_format=_('Note: Changes only take effect after logout.'))
-        dialog.run()
-        dialog.destroy()
+      dialog.connect('response', self._onNoA11yResponse)
+      dialog.show_all()
 
+  def _onNoA11yResponse(self, dialog, response_id):
+    dialog.destroy()
+    if response_id == gtk.RESPONSE_YES:
+      cl = gconf.client_get_default()
+      cl.set_bool('/desktop/gnome/interface/accessibility', True)
+      dialog = gtk.MessageDialog(
+        self.window,
+        type=gtk.MESSAGE_INFO,
+        buttons=gtk.BUTTONS_OK, 
+        message_format=_('Note: Changes only take effect after logout.'))
+      dialog.connect('response', lambda dia, resp: dia.destroy())
+      dialog.show_all()
+  
   def _shutDown(self):
     '''
     Cleans up any object instances that need explicit shutdown.
